@@ -3,35 +3,21 @@
 
 """Interact with functions using widgets."""
 
-from __future__ import print_function
-from __future__ import division
-
-try:  # Python >= 3.3
-    from inspect import signature, Parameter
-except ImportError:
-    from IPython.utils.signatures import signature, Parameter
+from collections.abc import Iterable, Mapping
+from inspect import signature, Parameter
 from inspect import getcallargs
-
-try:
-    from inspect import getfullargspec as check_argspec
-except ImportError:
-    from inspect import getargspec as check_argspec # py2
+from inspect import getfullargspec as check_argspec
 import sys
 
-from IPython.core.getipython import get_ipython
-from . import (ValueWidget, Text,
+from IPython import get_ipython
+from . import (Widget, ValueWidget, Text,
     FloatSlider, IntSlider, Checkbox, Dropdown,
     VBox, Button, DOMWidget, Output)
 from IPython.display import display, clear_output
-from ipython_genutils.py3compat import string_types, unicode_type
 from traitlets import HasTraits, Any, Unicode, observe
 from numbers import Real, Integral
 from warnings import warn
 
-try:
-    from collections.abc import Iterable, Mapping
-except ImportError:
-    from collections import Iterable, Mapping # py2
 
 
 empty = Parameter.empty
@@ -99,7 +85,7 @@ def _get_min_max_value(min, max, value=None, step=None):
     # Either min and max need to be given, or value needs to be given
     if value is None:
         if min is None or max is None:
-            raise ValueError('unable to infer range, value from: ({0}, {1}, {2})'.format(min, max, value))
+            raise ValueError('unable to infer range, value from: ({}, {}, {})'.format(min, max, value))
         diff = max - min
         value = min + (diff / 2)
         # Ensure that value has the same type as diff
@@ -125,22 +111,18 @@ def _get_min_max_value(min, max, value=None, step=None):
         tick = int((value - min) / step)
         value = min + tick * step
     if not min <= value <= max:
-        raise ValueError('value must be between min and max (min={0}, value={1}, max={2})'.format(min, value, max))
+        raise ValueError('value must be between min and max (min={}, value={}, max={})'.format(min, value, max))
     return min, max, value
 
 def _yield_abbreviations_for_parameter(param, kwargs):
     """Get an abbreviation for a function parameter."""
     name = param.name
     kind = param.kind
-    ann = param.annotation
     default = param.default
     not_found = (name, empty, empty)
     if kind in (Parameter.POSITIONAL_OR_KEYWORD, Parameter.KEYWORD_ONLY):
         if name in kwargs:
             value = kwargs.pop(name)
-        elif ann is not empty:
-            warn("Using function annotations to implicitly specify interactive controls is deprecated. Use an explicit keyword argument for the parameter instead.", DeprecationWarning)
-            value = ann
         elif default is not empty:
             value = default
         else:
@@ -165,7 +147,8 @@ class interactive(VBox):
         should match the function signature.
     __options : dict
         A dict of options. Currently, the only supported keys are
-        ``"manual"`` and ``"manual_name"``.
+        ``"manual"`` (defaults to ``False``), ``"manual_name"`` (defaults
+        to ``"Run Interact"``) and ``"auto_display"`` (defaults to ``False``).
     **kwargs : various, optional
         An interactive widget is created for each keyword argument that is a
         valid widget abbreviation.
@@ -225,12 +208,12 @@ class interactive(VBox):
             # invoke execution.
             for w in self.kwargs_widgets:
                 if isinstance(w, Text):
-                    w.on_submit(self.update)
+                    w.continuous_update = False
+                    w.observe(self.update, names='value')
         else:
             for widget in self.kwargs_widgets:
                 widget.observe(self.update, names='value')
-
-            self.on_displayed(self.update)
+            self.update()
 
     # Callback function
     def update(self, *args):
@@ -261,7 +244,7 @@ class interactive(VBox):
         except Exception as e:
             ip = get_ipython()
             if ip is None:
-                self.log.warn("Exception in interact callback: %s", e, exc_info=True)
+                self.log.warning("Exception in interact callback: %s", e, exc_info=True)
             else:
                 ip.showtraceback()
         finally:
@@ -295,13 +278,12 @@ class interactive(VBox):
         """Given a sequence of (name, abbrev, default) tuples, return a sequence of Widgets."""
         result = []
         for name, abbrev, default in seq:
+            if isinstance(abbrev, Widget) and (not isinstance(abbrev, ValueWidget)):
+                raise TypeError("{!r} is not a ValueWidget".format(abbrev))
             widget = self.widget_from_abbrev(abbrev, default)
-            if not (isinstance(widget, ValueWidget) or isinstance(widget, fixed)):
-                if widget is None:
-                    raise ValueError("{!r} cannot be transformed to a widget".format(abbrev))
-                else:
-                    raise TypeError("{!r} is not a ValueWidget".format(widget))
-            if not widget.description:
+            if widget is None:
+                raise ValueError("{!r} cannot be transformed to a widget".format(abbrev))
+            if not hasattr(widget, "description") or not widget.description:
                 widget.description = name
             widget._kwarg = name
             result.append(widget)
@@ -346,8 +328,8 @@ class interactive(VBox):
     @staticmethod
     def widget_from_single_value(o):
         """Make widgets from single values, which can be used as parameter defaults."""
-        if isinstance(o, string_types):
-            return Text(value=unicode_type(o))
+        if isinstance(o, str):
+            return Text(value=str(o))
         elif isinstance(o, bool):
             return Checkbox(value=o)
         elif isinstance(o, Integral):
@@ -400,7 +382,7 @@ class interactive(VBox):
         return _InteractFactory(cls, options)
 
 
-class _InteractFactory(object):
+class _InteractFactory:
     """
     Factory for instances of :class:`interactive`.
 
@@ -474,7 +456,7 @@ class _InteractFactory(object):
             # 1. Using interact as a function
             def greeting(text="World"):
                 print("Hello {}".format(text))
-            interact(greeting, text="IPython Widgets")
+            interact(greeting, text="Jupyter Widgets")
 
             # 2. Using interact as a decorator
             @interact
@@ -482,7 +464,7 @@ class _InteractFactory(object):
                 print("Hello {}".format(text))
 
             # 3. Using interact as a decorator with named parameters
-            @interact(text="IPython Widgets")
+            @interact(text="Jupyter Widgets")
             def greeting(text="World"):
                 print("Hello {}".format(text))
 
@@ -568,7 +550,7 @@ class fixed(HasTraits):
     value = Any(help="Any Python object")
     description = Unicode('', help="Any Python object")
     def __init__(self, value, **kwargs):
-        super(fixed, self).__init__(value=value, **kwargs)
+        super().__init__(value=value, **kwargs)
     def get_interact_value(self):
         """Return the value for this widget which should be passed to
         interactive functions. Custom widgets can change this method
