@@ -61,13 +61,7 @@ class Box(DOMWidget, CoreWidget):
 
     def __init__(self, children=(), **kwargs):
         kwargs['children'] = children
-        super(Box, self).__init__(**kwargs)
-        self.on_displayed(Box._fire_children_displayed)
-
-    def _fire_children_displayed(self):
-        for child in self.children:
-            child._handle_displayed()
-
+        super().__init__(**kwargs)
 
 @register
 @doc_subst(_doc_snippets)
@@ -111,6 +105,22 @@ class HBox(Box):
 
 @register
 class GridBox(Box):
+    """ Displays multiple widgets in rows and columns using the grid box model.
+
+    Parameters
+    ----------
+    {box_params}
+
+    Examples
+    --------
+    >>> import ipywidgets as widgets
+    >>> title_widget = widgets.HTML('<em>Grid Box Example</em>')
+    >>> slider = widgets.IntSlider()
+    >>> button1 = widgets.Button(description='1')
+    >>> button2 = widgets.Button(description='2')
+    >>> # Create a grid with two columns, splitting space equally
+    >>> layout = widgets.Layout(grid_template_columns='1fr 1fr')
+    >>> widgets.GridBox([title_widget, slider, button1, button2], layout=layout)
+    """
     _model_name = Unicode('GridBoxModel').tag(sync=True)
     _view_name = Unicode('GridBoxView').tag(sync=True)
- 
\ No newline at end of file
